#!/bin/bash

#     Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>
#
#            This script is released under the terms of the:
#                      GNU GENERAL PUBLIC LICENSE
#                        Version 3, 29 June 2007
#                http://www.gnu.org/licenses/gpl-3.0.txt
#
# This is a Bash shell script written to automate the process of
# generating software packages suitable for use with Zenwalk Linux.
#
# Zenwalk Linux is a GNU/Linux operating system.
#
#              For more information on Zenwalk Linux visit:
#                        http://www.zenwalk.org/
#
# Bash is a free software Unix shell written for the GNU Project.
#
#                   For more information on Bash visit:
#           http://tiswww.case.edu/php/chet/bash/bashtop.html


# Package variables:
#_______________________________________________________________________


Build_Root=$(pwd)
Flag_Arch="i686"
Source_Name="bluecurve-icon-theme"
Source_Version="8.0.2"
Source_Duo="${Source_Name}-${Source_Version}"
Source_Format="tar.bz2"
Source_Title="${Source_Duo}.${Source_Format}"
Source_URL="http://cvs.fedora.redhat.com/repo/pkgs/bluecurve-icon-theme/bluecurve-icon-theme-8.0.2.tar.bz2/3a3ecac0922f964bb1c4be617e8dec37/${Source_Title}"
Package_Name="bluecurve-cursors"
Package_Version="${Source_Version}"
Package_Duo="${Package_Name}-${Package_Version}"
Package_Arch="noarch"
Package_Release="62"
Package_Build="1"
Package_Title="${Package_Duo}-${Package_Arch}-${Package_Release}.${Package_Build}"
Package_Root="${Build_Root}/${Package_Title}"
Special_Docs=" "
Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"
File_Image=" "
File_Misc="Bluecurve.cursortheme.gz"
File_Patch=" "
File_Script=" \
	bluecurve-cursors-doinst.sh.gz \
	build-${Package_Name}.sh"
Custom_Files="${File_Image} ${File_Misc} ${File_Patch} ${File_Script}"

mkdir -p ${Package_Root}/install
cat <<EOF0 > ${Package_Root}/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also

                 |-----handy-ruler------------------------------------------------------|
${Package_Name}: ${Package_Name} (Bluecurve icon theme cursors)
${Package_Name}:
${Package_Name}: This package contains Bluecurve style cursors.
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
EOF0

mkdir -p ${Package_Root}/usr/src/${Package_Duo}
for Each_Custom in ${Custom_Files} ; do
	if [ -e ${Each_File} ]; then
		cp ${Each_Custom} \
			${Package_Root}/usr/src/${Package_Duo}/
	fi
done


# Build & install:
#_______________________________________________________________________
for Each in ${Source_Duo} ${Package_Name}-${Package_Version}-${Package_Arch} ; do
	if [ -d ${Each} ] ; then
		rm -rf ${Each}
	fi
done
for Each in ${Package_Title}.dep ${Package_Title}.md5 ${Package_Title}.src.md5 \
	${Package_Title}.src.tbz ${Package_Title}.tgz ; do
	if [ -e ${Each} ] ; then
		rm -rf ${Each}
	fi
done
if [ -e ${Source_Title} ] ; then
	echo "${Source_Title} already downloaded"
else
	wget -c -t 0 -T 50 -w 0 ${Source_URL}
fi

for Archive in ${Source_Title} ; do
	File_Type=$(file -biz "${Archive}")
	unset Command
	case "${File_Type}" in
		*application/x-tar*)
			Command="tar -xf" ;;
		*application/x-zip*)
			Command="unzip" ;;
		*application/x-gzip*)
			Command="gunzip -d -f" ;;
		*application/x-bzip*)
			Command="bunzip2 -f" ;;
	esac
	if [ "$Command" != "" ]; then
		echo "${Command} ${Archive}"
		${Command} ${Archive} || exit 1
	fi
done

cd ${Source_Duo}

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=${Flag_Arch} -pipe" 
export CXXFLAGS="${CFLAGS}" 
export PKG_CONFIG_PATH=/usr/lib/pkgconfig
./configure \
--prefix=/usr \
--bindir=/usr/bin \
--sbindir=/usr/sbin \
--libexecdir=/usr/libexec \
--datadir=/usr/share \
--sysconfdir=/etc \
--sharedstatedir=/usr/com \
--localstatedir=/var \
--libdir=/usr/lib \
--includedir=/usr/include \
--oldincludedir=/usr/include \
--infodir=/usr/info \
--mandir=/usr/man \
--silent

make --silent || exit 1
make install --silent  DESTDIR=${Package_Root} || exit 1

mkdir -p ${Package_Root}/usr/doc/${Package_Duo}/
for Each_Doc in {${Special_Docs},${Standard_Docs}} ; do
	if [ -e ${Each_Doc} ] ; then
		cp ${Each_Doc} ${Package_Root}/usr/doc/${Package_Duo}/
	fi
done

( cd ${Package_Root}/usr/doc/${Package_Duo}/
	find . -name "*" -size 0c -exec rm {} \;
)

cd ${Build_Root}
rm -rf ${Source_Duo}


# Special routines:
#_______________________________________________________________________
# Remove unnecessary bluecurve-icon-theme files since we are only after
# the cursors:
	(
		cd ${Package_Root}/usr/share
		rmdir locale
	)
	(
		cd ${Package_Root}/usr/share/icons
		rm -rf Bluecurve-inverse LBluecurve LBluecurve-inverse
	)
	(
		cd ${Package_Root}/usr/share/icons/Bluecurve
		rm -rf 16x16 20x20 24x24 32x32 36x36 48x48 64x64 96x96 Bluecurve.cursortheme index.theme
	)

# Enforce the use of the bluecurve cursors:
	mkdir -p ${Package_Root}/usr/share/icons/default
cat <<EOF1 > ${Package_Root}/usr/share/icons/default/index.theme
[Icon Theme]
Inherits=Bluecurve
EOF1
	zcat ${Build_Root}/Bluecurve.cursortheme.gz > \
		${Package_Root}/usr/share/icons/Bluecurve/Bluecurve.cursortheme


# Complete the final packaging routines:
#_______________________________________________________________________
( cd ${Package_Root}
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

if [ -d ${Package_Root}/usr/man ]; then
	( cd ${Package_Root}/usr/man
		gzip -9 */*
	)
fi

( cd ${Package_Root}
	requiredbuilder -z ${Package_Root} > ${Build_Root}/${Package_Title}.dep
)

( cd ${Package_Root}
	makepkg -l y -c n ${Build_Root}/${Package_Title}.tgz
)
cd ${Build_Root}
md5sum ${Package_Title}.tgz > ${Package_Title}.md5
rm -rf ${Package_Root}

mkdir -p ${Package_Root}.src
cp ${Source_Title} ${Package_Root}.src
for Each_Set in ${Custom_Files} ; do
	if [ -e ${Each_Set} ] ; then
		cp ${Each_Set} ${Package_Root}.src
	fi
done
tar -jcf ${Package_Title}.src.tbz ${Package_Title}.src
rm -rf ${Package_Title}.src 
md5sum ${Package_Title}.src.tbz > ${Package_Title}.src.md5


# Changelog of script edits:
#_______________________________________________________________________


# ~ Date: 		Thu Feb 19th 2009
# ~ Editor:		Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Changes:	n/a (Original script creation)
