#!/bin/bash

#     Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>
#
#            This script is released under the terms of the:
#                      GNU GENERAL PUBLIC LICENSE
#                        Version 3, 29 June 2007
#                http://www.gnu.org/licenses/gpl-3.0.txt
#
# This is a Bash shell script written to automate the process of
# generating software packages suitable for use with Zenwalk Linux.
#
# Zenwalk Linux is a GNU/Linux operating system.
#
#              For more information on Zenwalk Linux visit:
#                        http://www.zenwalk.org/
#
# Bash is a free software Unix shell written for the GNU Project.
#
#                   For more information on Bash visit:
#           http://tiswww.case.edu/php/chet/bash/bashtop.html


# Package variables:
#_______________________________________________________________________
Summary="Data required for the X Server"
Package_Name="xorg-data"
Package_Version="7.4"
Package_Arch="i686"
Package_Release="62"
Package_Build="2"
File_Package=" \
	bluecurve-cursors-8.0.2-noarch-62.1.tgz \
	hwdata-0.222-i686-62.1.tgz \
	xorg-data-cursors-1.0.1-noarch-62.1.tgz \
	xorg-icons-0.1-noarch-62.1.tgz \
	xorg-data-xbitmaps-1.0.1-i686-62.1.tgz \
	xorg-data-xkeyboard-config-1.5-noarch-62.1.tgz"
File_Image=" \
	xorg-icon-0.2.tar.bz2"
File_Misc=" \
	gpl-3.0.txt.gz"
File_Patch=" "
File_Script=" \
	build-${Package_Name}.sh"
Special_Docs=" "
Desc_Line_00=": (${Summary})"
Desc_Line_01=":"
Desc_Line_02=": This package contains data required for the X.Org X server"
Desc_Line_03=": (Xorg) to function properly. Inside is software such as:"
Desc_Line_04=": xbitmaps: the base X bitmaps, which are used in many legacy"
Desc_Line_05=": X clients, xcursor-themes: the base X cursor themes"
Desc_Line_06=": -- handhelds, redglass, and whiteglass and xkeyboard-config"
Desc_Line_07=": which contains the keyboard configuration database for the"
Desc_Line_08=": X Window System."
Desc_Line_09=":"
Desc_Line_10=":"
# BuildRequires: 
# Requires:


# Constant variables:
#_______________________________________________________________________
Build_Root=$(pwd)
Package_Duo="${Package_Name}-${Package_Version}"
Package_Title="${Package_Duo}-${Package_Arch}-${Package_Release}.${Package_Build}"
Package_Root="${Build_Root}/${Package_Title}"


# Build & install:
#_______________________________________________________________________
if [ -d ${Package_Name}-${Package_Version}-${Package_Arch} ] ; then
	rm -rf ${Package_Name}-${Package_Version}-${Package_Arch}
fi
for Each in ${Package_Title}.dep ${Package_Title}.md5 ${Package_Title}.src.md5 \
	${Package_Title}.src.tbz ${Package_Title}.tgz ; do
	if [ -e ${Each} ] ; then
		rm -rf ${Each}
	fi
done

mkdir -p ${Package_Root}/usr/doc/${Package_Duo}/
zcat ${Build_Root}/gpl-3.0.txt.gz > ${Package_Root}/usr/doc/${Package_Duo}/COPYING

mkdir -p ${Package_Root}/install
mkdir -p ${Package_Root}/usr/src/${Package_Duo}

for Each in ${File_Package} ; do
	mkdir ${Build_Root}/Pkg_Temp
	cd ${Build_Root}/Pkg_Temp
	explodepkg ../${Each} .
	rm install/slack-desc
	cat install/doinst.sh >> ${Package_Root}/install/doinst.sh
	rm -rf install/
	( cd usr/src ; cp -aR * ${Package_Root}/usr/src/${Package_Duo}/ )
	rm -rf usr/src
	cp -aR * ${Package_Root}/
	cd ${Build_Root}
	rm -rf Pkg_Temp
done

cd ${Package_Root}/usr/src/*
mkdir individual-build-srcipts
mv * individual-build-srcipts
tar jcf individual-build-srcipts.tar.bz2 individual-build-srcipts/
rm -rf individual-build-srcipts

cd ${Build_Root}
tar xf xorg-icon-0.2.tar.bz2
cd xorg-icon-0.2
mkdir -p ${Package_Root}/usr/share/icons/hicolor
mv 16x16 192x192 22x22 24x24 32x32 36x36 48x48 64x64 72x72 96x96 128x128 scalable \
${Package_Root}/usr/share/icons/hicolor/
( cd ${Build_Root} ; rm -rf xorg-icon-0.2 )


# Complete the final packaging routines:
#_______________________________________________________________________
mkdir ${Package_Root}/install
cat <<EOF1 > ${Package_Root}/install/slack-desc
${Package_Name}${Desc_Line_00}
${Package_Name}${Desc_Line_01}
${Package_Name}${Desc_Line_02}
${Package_Name}${Desc_Line_03}
${Package_Name}${Desc_Line_04}
${Package_Name}${Desc_Line_05}
${Package_Name}${Desc_Line_06}
${Package_Name}${Desc_Line_07}
${Package_Name}${Desc_Line_08}
${Package_Name}${Desc_Line_09}
${Package_Name}${Desc_Line_10}
EOF1

cd ${Build_Root}
cp ${File_Misc} ${File_Script} ${Package_Root}/usr/src/${Package_Duo}

( cd ${Package_Root} ;
	requiredbuilder -z ${Package_Root} > ${Build_Root}/${Package_Title}.dep
)

( cd ${Package_Root}
	makepkg -l y -c n ${Build_Root}/${Package_Title}.tgz
)
cd ${Build_Root}
md5sum ${Package_Title}.tgz > ${Package_Title}.md5
rm -rf ${Package_Root}

mkdir -p ${Package_Root}.src
cp ${File_Misc} ${File_Script} ${Package_Root}.src
tar -jcf ${Package_Title}.src.tbz ${Package_Title}.src
rm -rf ${Package_Title}.src 
md5sum ${Package_Title}.src.tbz > ${Package_Title}.src.md5


# Changelog of script edits:
#_______________________________________________________________________


# ~ Date: 		Fri Mar 13th 2009
# ~ Editor:		Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Changes:	(Rebuilt over gcc-4.3.3)

# ~ Date: 		Thu Mar 5th 2009
# ~ Editor:		Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Changes:	n/a (Original script creation)
